Trait Elastic

pub trait Elastic: RuntimeType + MaxEncodedLen { }
Upper-bounded encoded-size runtime type with flexible internal structure.

Extends RuntimeType with [MaxEncodedLen], guaranteeing a predictable upper bound on encoded size while allowing structural flexibility (e.g. weak-bounded collections).

Unlike Delimited, this does not require 'static, so it may be used in temporary or lifetime-bound contexts. Add Storable when persistence is required.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T> Elastic for T
where T: RuntimeType + MaxEncodedLen,